==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/StringMatchRegexFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class StringMatchRegexFluent<A extends StringMatchRegexFluent<A>> extends BaseFluent<A>{
  public StringMatchRegexFluent() {
  }
  public StringMatchRegexFluent(StringMatchRegex instance) {
    instance = (instance != null ? instance : new StringMatchRegex());

    if (instance != null) {
      this.withRegex(instance.getRegex());
      this.withRegex(instance.getRegex());
    }
  }
  private String regex;
  public String getRegex() {
    return this.regex;
  }
  public A withRegex(String regex) {
    this.regex=regex; return (A) this;
  }
  public boolean hasRegex() {
    return this.regex != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchRegexFluent that = (StringMatchRegexFluent) o;
    if (!java.util.Objects.equals(regex, that.regex)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(regex,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (regex != null) { sb.append("regex:"); sb.append(regex); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/StringMatchRegexFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class StringMatchRegexFluent<A extends StringMatchRegexFluent<A>> extends BaseFluent<A>{
  public StringMatchRegexFluent() {
  }
  
  public StringMatchRegexFluent(StringMatchRegex instance) {
    this.copyInstance(instance);
  }
  private String regex;
  
  protected void copyInstance(StringMatchRegex instance) {
    instance = (instance != null ? instance : new StringMatchRegex());
  
    if (instance != null) {
        this.withRegex(instance.getRegex());
        this.withRegex(instance.getRegex());
      }
  }
  
  public String getRegex() {
    return this.regex;
  }
  
  public A withRegex(String regex) {
    this.regex=regex; return (A) this;
  }
  
  public boolean hasRegex() {
    return this.regex != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    StringMatchRegexFluent that = (StringMatchRegexFluent) o;
    if (!java.util.Objects.equals(regex, that.regex)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(regex,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (regex != null) { sb.append("regex:"); sb.append(regex); }
    sb.append("}");
    return sb.toString();
  }
  

}
